HiParameter class

Constructors

HiParameter()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

accept → const String
arguments → const String
canLoadMore → const String
canRefresh → const String
code → const String
color → const String
configuration → const String
context → const String
data → const String
detail → const String
extra → const String
height → const String
hideAppBar → const String
hideIcon → const String
hideNavLine → const String
id → const String
index → const String
indicated → const String
isPhysicalDevice → const String
isTop → const String
items → const String
jsonEncoding → const String
key → const String
machine → const String
mode → const String
model → const String
name → const String
needReload → const String
pageFirst → const String
pageIndex → const String
pageSize → const String
path → const String
routerMode → const String
routerRoot → const String
selected → const String
separated → const String
systemName → const String
systemVersion → const String
tab → const String
tabBarHeight → const String
tabs → const String
text → const String
title → const String
token → const String
transparentAppBar → const String
type → const String
url → const String
user → const String
username → const String
utsname → const String
value → const String